pub fn missing_field<T: Deserialize>(
field_name: &'static str,
) -> Result<T, Error>Expand description
Returns the initial value for a field that is missing.
pub fn missing_field<T: Deserialize>(
field_name: &'static str,
) -> Result<T, Error>Returns the initial value for a field that is missing.